pub struct NewOrder {
pub order: NewOrderData,
pub owner: String,
pub order_type: OrderType,
pub defer_exec: bool,
pub post_only: Option<bool>,
}Expand description
NewOrder is the payload structure for posting orders to the API It wraps SignedOrder with orderType, owner, and deferExec fields
Fields
order: NewOrderDataowner: Stringorder_type: OrderTypedefer_exec: boolpost_only: Option<bool>Post-only orders will be rejected if they would immediately match (added in v5.2.0) Only supported for GTC and GTD orders