pub struct ClobClient {
pub host: String,
pub chain_id: i64,
pub signer: Option<Arc<EthersSigner>>,
pub creds: Option<ApiKeyCreds>,
pub use_server_time: bool,
pub geo_block_token: Option<String>,
pub tick_sizes: HashMap<String, String>,
pub neg_risk: HashMap<String, bool>,
pub fee_rates: HashMap<String, f64>,
pub builder_signer: Option<BuilderSigner>,
pub builder_config: Option<BuilderConfig>,
}Fields
host: Stringchain_id: i64signer: Option<Arc<EthersSigner>>creds: Option<ApiKeyCreds>use_server_time: boolgeo_block_token: Option<String>Optional geo block token passed as query parameter geo_block_token.
TypeScript SDK 行为:只要在 client 上配置了该 token,则所有 HTTP 请求都会自动携带
geo_block_token query 参数。Rust SDK 这里保持一致:统一在 HTTP 入口封装层注入。
tick_sizes: HashMap<String, String>neg_risk: HashMap<String, bool>fee_rates: HashMap<String, f64>builder_signer: Option<BuilderSigner>builder_config: Option<BuilderConfig>Implementations
Sourceimpl ClobClient
impl ClobClient
Sourcepub async fn getMarkets(
&self,
params: Option<HashMap<String, String>>,
) -> Result<Vec<Market>, ClobError>
pub async fn getMarkets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
TS parity alias for get_markets (camelCase). Prefer get_markets in Rust.
Sourcepub async fn getMarket(
&self,
market_id: &str,
params: Option<HashMap<String, String>>,
) -> Result<MarketSummary, ClobError>
pub async fn getMarket( &self, market_id: &str, params: Option<HashMap<String, String>>, ) -> Result<MarketSummary, ClobError>
TS parity alias for getMarket -> get_market.
pub async fn getOrderBook( &mut self, token_id: &str, ) -> Result<OrderBookSummary, ClobError>
pub async fn getTickSize(&mut self, token_id: &str) -> Result<String, ClobError>
pub async fn getNegRisk(&mut self, token_id: &str) -> Result<bool, ClobError>
pub async fn getFeeRate(&mut self, token_id: &str) -> Result<f64, ClobError>
pub async fn getOpenOrders( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<SignedOrder>, ClobError>
pub async fn getOrder(&self, order_id: &str) -> Result<OpenOrder, ClobError>
pub async fn postSignedOrder( &self, signed_order: &SignedOrder, ) -> Result<OrderResponse, ClobError>
pub async fn postOrders( &self, orders: Vec<SignedOrder>, defer_exec: bool, ) -> Result<Vec<Order>, ClobError>
pub async fn createOrder( &mut self, user_order: UserOrder, options_tick: Option<&str>, ) -> Result<SignedOrder, ClobError>
pub async fn createMarketOrder( &mut self, user_market_order: UserMarketOrder, options_tick: Option<&str>, ) -> Result<SignedOrder, ClobError>
pub async fn createAndPostOrder( &mut self, user_order: UserOrder, options_tick: Option<&str>, ) -> Result<OrderResponse, ClobError>
pub async fn createAndPostMarketOrder( &mut self, user_market_order: UserMarketOrder, options_tick: Option<&str>, ) -> Result<OrderResponse, ClobError>
Sourcepub async fn cancelOrder(
&self,
payload: OrderPayloadParity,
) -> Result<Value, ClobError>
pub async fn cancelOrder( &self, payload: OrderPayloadParity, ) -> Result<Value, ClobError>
TypeScript parity: cancelOrder({ orderID }) 发送 DELETE /orders 携带 JSON body。
pub async fn cancelOrders( &self, order_ids: Vec<String>, ) -> Result<Vec<Order>, ClobError>
pub async fn cancelAll(&self) -> Result<Vec<Order>, ClobError>
pub async fn cancelMarketOrders( &self, payload: OrderMarketCancelParams, ) -> Result<Vec<Order>, ClobError>
pub async fn isOrderScoring( &self, params: Option<HashMap<String, String>>, ) -> Result<OrderScoring, ClobError>
pub async fn areOrdersScoring( &self, order_ids: Option<Vec<String>>, ) -> Result<OrdersScoring, ClobError>
pub async fn getTrades( &self, params: Option<HashMap<String, String>>, only_first_page: bool, next_cursor: Option<String>, ) -> Result<Vec<Value>, ClobError>
pub async fn getTradesTyped( &self, params: Option<HashMap<String, String>>, only_first_page: bool, next_cursor: Option<String>, ) -> Result<Vec<Trade>, ClobError>
pub async fn getNotifications(&self) -> Result<Vec<Notification>, ClobError>
pub async fn dropNotifications( &self, ids: Option<&Vec<String>>, ) -> Result<(), ClobError>
pub async fn getBalanceAllowance( &self, params: Option<HashMap<String, String>>, ) -> Result<BalanceAllowanceResponse, ClobError>
pub async fn updateBalanceAllowance( &self, params: Option<HashMap<String, String>>, ) -> Result<(), ClobError>
pub async fn getTime(&self) -> Result<u64, ClobError>
pub async fn getApiKeys(&self) -> Result<Vec<ApiKeyCreds>, ClobError>
pub async fn deleteApiKey(&self) -> Result<(), ClobError>
pub async fn getClosedOnlyMode(&self) -> Result<BanStatus, ClobError>
pub async fn createApiKey( &self, nonce: Option<u64>, ) -> Result<ApiKeyCreds, ClobError>
pub async fn deriveApiKey( &self, params: Option<HashMap<String, String>>, ) -> Result<ApiKeyCreds, ClobError>
pub async fn createBuilderApiKey(&self) -> Result<ApiKeyCreds, ClobError>
pub async fn getBuilderApiKeys(&self) -> Result<Vec<ApiKeyCreds>, ClobError>
pub async fn revokeBuilderApiKey(&self) -> Result<(), ClobError>
pub async fn getSimplifiedMarkets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn getSamplingMarkets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn getSamplingSimplifiedMarkets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn getOrderBooks( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<OrderBookSummary>, ClobError>
pub async fn getMidpoint( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn getMidpoints( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn getPrices( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn getSpreads( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn getLastTradesPrices( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn getPricesHistory( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn getMarketTradesEvents( &self, market_id: &str, params: Option<HashMap<String, String>>, ) -> Result<Vec<Trade>, ClobError>
pub async fn getBuilderTrades( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<BuilderTrade>, ClobError>
pub async fn getEarningsForUserForDay( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub async fn getEarningsForUserForDayTyped( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub async fn getTotalEarningsForUserForDay( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub async fn getLiquidityRewardPercentages( &self, params: Option<HashMap<String, String>>, ) -> Result<HashMap<String, f64>, ClobError>
pub async fn getRewardsMarketsCurrent( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub async fn getRewardsEarningsPercentages( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub fn new( host: &str, chain_id: i64, signer: Option<Arc<EthersSigner>>, creds: Option<ApiKeyCreds>, use_server_time: bool, ) -> Self
pub fn with_geo_block_token(self, token: String) -> Self
pub fn set_geo_block_token(&mut self, token: Option<String>)
Sourcepub fn with_builder_signer(
self,
key: String,
secret_b64: String,
passphrase: String,
) -> Self
pub fn with_builder_signer( self, key: String, secret_b64: String, passphrase: String, ) -> Self
Configure Builder API signer (builder auth). Secret must be base64 encoded.
Sourcepub fn with_builder_config(self, cfg: ObBuilderConfig) -> Self
pub fn with_builder_config(self, cfg: ObBuilderConfig) -> Self
Set a default builder config for order creation (tick size, neg risk, signature type, funder).
Sourcepub fn rfq(&mut self) -> RfqClient<'_>
pub fn rfq(&mut self) -> RfqClient<'_>
RFQ entrypoint.
使用方式:client.rfq().get_rfq_quotes(...)。
注意:RFQ 的 accept/approve 需要在本地创建并签名订单,因此会对 self 持有可变借用。
pub async fn get_order_book( &mut self, token_id: &str, ) -> Result<OrderBookSummary, ClobError>
pub async fn get_tick_size( &mut self, token_id: &str, ) -> Result<String, ClobError>
pub async fn get_neg_risk(&mut self, token_id: &str) -> Result<bool, ClobError>
pub async fn get_fee_rate(&mut self, token_id: &str) -> Result<f64, ClobError>
Sourcepub async fn post_order(
&self,
signed_order: &SignedOrder,
) -> Result<OrderResponse, ClobError>
pub async fn post_order( &self, signed_order: &SignedOrder, ) -> Result<OrderResponse, ClobError>
Convenience method that accepts a typed SignedOrder and posts it to the
API. Delegates to post_signed_order which performs serialization,
header creation and response parsing. Uses default orderType=GTC.
pub async fn get_api_keys(&self) -> Result<Vec<ApiKeyCreds>, ClobError>
Sourcepub async fn create_readonly_api_key(
&self,
) -> Result<ReadonlyApiKeyResponse, ClobError>
pub async fn create_readonly_api_key( &self, ) -> Result<ReadonlyApiKeyResponse, ClobError>
Creates a new readonly API key for the current (L2 authenticated) user.
TS parity: createReadonlyApiKey(): Promise<{ apiKey: string }>
Sourcepub async fn get_readonly_api_keys(&self) -> Result<Vec<String>, ClobError>
pub async fn get_readonly_api_keys(&self) -> Result<Vec<String>, ClobError>
Lists readonly API keys for the current (L2 authenticated) user.
TS parity: getReadonlyApiKeys(): Promise<string[]>
Sourcepub async fn delete_readonly_api_key(
&self,
key: &str,
) -> Result<bool, ClobError>
pub async fn delete_readonly_api_key( &self, key: &str, ) -> Result<bool, ClobError>
Deletes a readonly API key for the current (L2 authenticated) user.
TS parity: deleteReadonlyApiKey(key: string): Promise<boolean>
Sourcepub async fn validate_readonly_api_key(
&self,
address: &str,
key: &str,
) -> Result<String, ClobError>
pub async fn validate_readonly_api_key( &self, address: &str, key: &str, ) -> Result<String, ClobError>
Validates a readonly API key for a given address.
TS parity: validateReadonlyApiKey(address: string, key: string): Promise<string>
Note: This endpoint is treated as public (no L1/L2 auth headers).
pub async fn createReadonlyApiKey( &self, ) -> Result<ReadonlyApiKeyResponse, ClobError>
pub async fn getReadonlyApiKeys(&self) -> Result<Vec<String>, ClobError>
pub async fn deleteReadonlyApiKey(&self, key: &str) -> Result<bool, ClobError>
pub async fn validateReadonlyApiKey( &self, address: &str, key: &str, ) -> Result<String, ClobError>
pub async fn get_closed_only_mode(&self) -> Result<BanStatus, ClobError>
pub async fn delete_api_key(&self) -> Result<(), ClobError>
pub async fn get_trades( &self, params: Option<HashMap<String, String>>, only_first_page: bool, next_cursor: Option<String>, ) -> Result<Vec<Value>, ClobError>
Sourcepub async fn get_trades_typed(
&self,
params: Option<HashMap<String, String>>,
only_first_page: bool,
next_cursor: Option<String>,
) -> Result<Vec<Trade>, ClobError>
pub async fn get_trades_typed( &self, params: Option<HashMap<String, String>>, only_first_page: bool, next_cursor: Option<String>, ) -> Result<Vec<Trade>, ClobError>
Typed variant of get_trades that deserializes each trade into Trade.
pub async fn get_notifications(&self) -> Result<Vec<Notification>, ClobError>
Sourcepub async fn get_notifications_typed(
&self,
) -> Result<Vec<Notification>, ClobError>
pub async fn get_notifications_typed( &self, ) -> Result<Vec<Notification>, ClobError>
Typed variant of get_notifications that deserializes notifications into Notification.
pub async fn drop_notifications( &self, ids: Option<&Vec<String>>, ) -> Result<(), ClobError>
pub async fn get_balance_allowance( &self, params: Option<HashMap<String, String>>, ) -> Result<BalanceAllowanceResponse, ClobError>
pub async fn update_balance_allowance( &self, params: Option<HashMap<String, String>>, ) -> Result<(), ClobError>
Sourcepub async fn get_rewards_user_for_day_typed(
&self,
params: Option<HashMap<String, String>>,
) -> Result<Vec<Reward>, ClobError>
pub async fn get_rewards_user_for_day_typed( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Typed helper to fetch user rewards for a day (deserializes into Reward).
This endpoint may be public or require params depending on server; we accept optional query params.
pub async fn create_order( &self, user_order: UserOrder, options_tick: Option<&str>, ) -> Result<SignedOrder, ClobError>
pub async fn create_market_order( &self, user_market_order: UserMarketOrder, options_tick: Option<&str>, ) -> Result<SignedOrder, ClobError>
pub async fn post_orders( &self, args: Vec<SignedOrder>, _defer_exec: bool, ) -> Result<Vec<Order>, ClobError>
Sourcepub async fn post_signed_order(
&self,
signed_order: &SignedOrder,
order_type: OrderType,
defer_exec: bool,
) -> Result<OrderResponse, ClobError>
pub async fn post_signed_order( &self, signed_order: &SignedOrder, order_type: OrderType, defer_exec: bool, ) -> Result<OrderResponse, ClobError>
Helper: post a single SignedOrder (typed) to the API. Wraps SignedOrder in NewOrder with orderType and performs L2-authenticated POST to POST_ORDER endpoint.
Sourcepub async fn post_signed_order_typed(
&self,
signed_order: &SignedOrder,
order_type: OrderType,
defer_exec: bool,
) -> Result<OrderResponse, ClobError>
pub async fn post_signed_order_typed( &self, signed_order: &SignedOrder, order_type: OrderType, defer_exec: bool, ) -> Result<OrderResponse, ClobError>
Typed variant of posting a signed order: posts the signed order and attempts to
deserialize the response into an OrderResponse (or into the data field if present).
Sourcepub async fn create_and_post_order(
&mut self,
user_order: UserOrder,
options_tick: Option<&str>,
order_type: Option<OrderType>,
) -> Result<OrderResponse, ClobError>
pub async fn create_and_post_order( &mut self, user_order: UserOrder, options_tick: Option<&str>, order_type: Option<OrderType>, ) -> Result<OrderResponse, ClobError>
Convenience: create (build & sign) then immediately post a limit order. orderType defaults to GTC (Good Till Cancelled).
Sourcepub async fn create_and_post_market_order(
&mut self,
user_market_order: UserMarketOrder,
options_tick: Option<&str>,
order_type: Option<OrderType>,
) -> Result<OrderResponse, ClobError>
pub async fn create_and_post_market_order( &mut self, user_market_order: UserMarketOrder, options_tick: Option<&str>, order_type: Option<OrderType>, ) -> Result<OrderResponse, ClobError>
Convenience: create (build & sign) then immediately post a market order. orderType defaults to FOK (Fill Or Kill).
Sourcepub async fn post_orders_typed(
&self,
orders: Vec<SignedOrder>,
_defer_exec: bool,
) -> Result<Value, ClobError>
pub async fn post_orders_typed( &self, orders: Vec<SignedOrder>, _defer_exec: bool, ) -> Result<Value, ClobError>
Helper: accept typed SignedOrder list and post them to POST_ORDERS endpoint.
Sourcepub async fn post_orders_typed_parsed(
&self,
orders: Vec<SignedOrder>,
_defer_exec: bool,
) -> Result<Vec<Order>, ClobError>
pub async fn post_orders_typed_parsed( &self, orders: Vec<SignedOrder>, _defer_exec: bool, ) -> Result<Vec<Order>, ClobError>
Post typed orders and return parsed Vec<Order> from the response.
This wraps the existing post_orders_typed which returns a raw JSON Value
and attempts to parse either a top-level array or data field into Vec<Order>.
pub async fn cancel_all(&self) -> Result<Vec<Order>, ClobError>
pub async fn cancel_market_orders( &self, payload: OrderMarketCancelParams, ) -> Result<Vec<Order>, ClobError>
pub async fn is_order_scoring( &self, params: Option<HashMap<String, String>>, ) -> Result<OrderScoring, ClobError>
pub async fn are_orders_scoring( &self, order_ids: Option<Vec<String>>, ) -> Result<OrdersScoring, ClobError>
Sourcepub async fn cancel_order_payload(
&self,
payload: OrderPayloadParity,
) -> Result<Order, ClobError>
pub async fn cancel_order_payload( &self, payload: OrderPayloadParity, ) -> Result<Order, ClobError>
Parity version using JSON body { orderID } instead of query param.
Sourcepub async fn cancel_order_payload_raw(
&self,
payload: OrderPayloadParity,
) -> Result<Value, ClobError>
pub async fn cancel_order_payload_raw( &self, payload: OrderPayloadParity, ) -> Result<Value, ClobError>
Raw JSON variant: return the API response as serde_json::Value (parity with TS any).
pub async fn cancel_orders( &self, order_ids: Vec<String>, ) -> Result<Vec<Order>, ClobError>
pub async fn get_order(&self, order_id: &str) -> Result<OpenOrder, ClobError>
Sourcepub async fn get_order_typed(
&self,
order_id: &str,
) -> Result<OpenOrder, ClobError>
pub async fn get_order_typed( &self, order_id: &str, ) -> Result<OpenOrder, ClobError>
Typed variant: try to deserialize an order response into OpenOrder.
pub async fn get_open_orders( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<SignedOrder>, ClobError>
Sourcepub async fn get_open_orders_typed(
&self,
params: Option<HashMap<String, String>>,
) -> Result<Vec<SignedOrder>, ClobError>
pub async fn get_open_orders_typed( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<SignedOrder>, ClobError>
Typed variant: try to deserialize open orders data into Vec
pub async fn get_markets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn get_market( &self, market_id: &str, params: Option<HashMap<String, String>>, ) -> Result<MarketSummary, ClobError>
pub async fn get_simplified_markets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn get_sampling_markets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn get_server_time(&self) -> Result<u64, ClobError>
pub async fn create_api_key( &self, nonce: Option<u64>, ) -> Result<ApiKeyCreds, ClobError>
pub async fn derive_api_key( &self, params: Option<HashMap<String, String>>, ) -> Result<ApiKeyCreds, ClobError>
pub async fn create_builder_api_key(&self) -> Result<ApiKeyCreds, ClobError>
pub async fn get_builder_api_keys(&self) -> Result<Vec<ApiKeyCreds>, ClobError>
pub async fn revoke_builder_api_key(&self) -> Result<(), ClobError>
pub async fn get_sampling_simplified_markets( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Market>, ClobError>
pub async fn get_order_books( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<OrderBookSummary>, ClobError>
pub async fn get_midpoint( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn get_midpoints( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn get_prices( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn get_spreads( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn get_last_trades_prices( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn get_prices_history( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<MarketPrice>, ClobError>
pub async fn get_market_trades_events( &self, market_id: &str, params: Option<HashMap<String, String>>, ) -> Result<Vec<Trade>, ClobError>
pub async fn get_earnings_for_user_for_day( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub async fn get_total_earnings_for_user_for_day( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Sourcepub async fn get_total_earnings_for_user_for_day_typed(
&self,
params: Option<HashMap<String, String>>,
) -> Result<Vec<Reward>, ClobError>
pub async fn get_total_earnings_for_user_for_day_typed( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Typed wrapper for total earnings for user for day. Attempts to parse an array of Reward.
pub async fn get_liquidity_reward_percentages( &self, params: Option<HashMap<String, String>>, ) -> Result<HashMap<String, f64>, ClobError>
Sourcepub async fn get_liquidity_reward_percentages_typed(
&self,
params: Option<HashMap<String, String>>,
) -> Result<HashMap<String, f64>, ClobError>
pub async fn get_liquidity_reward_percentages_typed( &self, params: Option<HashMap<String, String>>, ) -> Result<HashMap<String, f64>, ClobError>
Typed wrapper for liquidity reward percentages. Attempts to parse into a map of market -> percentage.
pub async fn get_rewards_markets_current( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
pub async fn get_rewards_markets( &self, market_id: &str, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Sourcepub async fn get_rewards_markets_typed(
&self,
market_id: &str,
params: Option<HashMap<String, String>>,
) -> Result<Vec<Reward>, ClobError>
pub async fn get_rewards_markets_typed( &self, market_id: &str, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Typed wrapper for get_rewards_markets (per-market rewards). Returns Vec
pub async fn get_rewards_earnings_percentages( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Sourcepub async fn get_rewards_earnings_percentages_typed(
&self,
params: Option<HashMap<String, String>>,
) -> Result<Vec<Reward>, ClobError>
pub async fn get_rewards_earnings_percentages_typed( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<Reward>, ClobError>
Typed wrapper for rewards earnings percentages. Returns Vec
pub async fn get_builder_trades( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<BuilderTrade>, ClobError>
Sourcepub async fn get_builder_trades_typed(
&self,
params: Option<HashMap<String, String>>,
) -> Result<Vec<BuilderTrade>, ClobError>
pub async fn get_builder_trades_typed( &self, params: Option<HashMap<String, String>>, ) -> Result<Vec<BuilderTrade>, ClobError>
Typed variant for builder trades (kept for compatibility)